get_circuit_description_hash_as_field_elems

Function get_circuit_description_hash_as_field_elems 

pub fn get_circuit_description_hash_as_field_elems<F: Field>(
    circuit_description: &GKRCircuitDescription<F>,
    circuit_description_hash_type: CircuitHashType,
) -> Vec<F>
Returns an equivalent set of field elements to be absorbed into a transcript, given a circuit description and the type of hash function to be used.

Arguments

  • circuit_description - The circuit description to be hashed and added to transcript.
  • circuit_description_hash_type - The type of hash function to be used.