test_circuit_internal

Function test_circuit_internal 

fn test_circuit_internal<F: Halo2FFTFriendlyField>(
    provable_circuit: &ProvableCircuit<F>,
)
Function which instantiates a circuit description with the given inputs and precommits and both attempts to both prove and verify said circuit.

Note that this function assumes that the prover is providing all of the circuit’s public inputs. This should not be the case in production, e.g. if there is a lookup argument involved, since the lookup table should be generated via a transparent setup and the verifier should know all the values (or be able to evaluate the MLE of such at a random challenge point).