fn verify_circuit_internal<F: Halo2FFTFriendlyField, Tr: TranscriptSponge<F>>(
verifiable_circuit: &VerifiableCircuit<F>,
proof_config: &ProofConfig,
proof_as_transcript: TranscriptReader<F, Tr>,
)Expand description
Takes in a verifier-ready VerifiableCircuit<F>, proof config [ProofConfig]
and GKR proof in the form of a [TranscriptReader<F, Tr>], and attempts to
verify the proof against the circuit.
Additionally, takes in a map of public inputs which are already known to the verifier. These will be checked against the values provided by the prover in transcript.